==> kubernetes-model-core-7.1.0-sources.jar: io/fabric8/kubernetes/api/model/clusterapi/v1beta1/MachineReadinessGateFluent.java <==
package io.fabric8.kubernetes.api.model.clusterapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class MachineReadinessGateFluent<A extends MachineReadinessGateFluent<A>> extends BaseFluent<A>{
  public MachineReadinessGateFluent() {
  }
  
  public MachineReadinessGateFluent(MachineReadinessGate instance) {
    this.copyInstance(instance);
  }
  private String conditionType;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(MachineReadinessGate instance) {
    instance = (instance != null ? instance : new MachineReadinessGate());
    if (instance != null) {
          this.withConditionType(instance.getConditionType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getConditionType() {
    return this.conditionType;
  }
  
  public A withConditionType(String conditionType) {
    this.conditionType = conditionType;
    return (A) this;
  }
  
  public boolean hasConditionType() {
    return this.conditionType != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachineReadinessGateFluent that = (MachineReadinessGateFluent) o;
    if (!java.util.Objects.equals(conditionType, that.conditionType)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(conditionType,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditionType != null) { sb.append("conditionType:"); sb.append(conditionType + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> kubernetes-model-core-7.4.0-sources.jar: io/fabric8/kubernetes/api/model/clusterapi/v1beta1/MachineReadinessGateFluent.java <==
package io.fabric8.kubernetes.api.model.clusterapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class MachineReadinessGateFluent<A extends MachineReadinessGateFluent<A>> extends BaseFluent<A>{
  public MachineReadinessGateFluent() {
  }
  
  public MachineReadinessGateFluent(MachineReadinessGate instance) {
    this.copyInstance(instance);
  }
  private String conditionType;
  private String polarity;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(MachineReadinessGate instance) {
    instance = (instance != null ? instance : new MachineReadinessGate());
    if (instance != null) {
          this.withConditionType(instance.getConditionType());
          this.withPolarity(instance.getPolarity());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getConditionType() {
    return this.conditionType;
  }
  
  public A withConditionType(String conditionType) {
    this.conditionType = conditionType;
    return (A) this;
  }
  
  public boolean hasConditionType() {
    return this.conditionType != null;
  }
  
  public String getPolarity() {
    return this.polarity;
  }
  
  public A withPolarity(String polarity) {
    this.polarity = polarity;
    return (A) this;
  }
  
  public boolean hasPolarity() {
    return this.polarity != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachineReadinessGateFluent that = (MachineReadinessGateFluent) o;
    if (!java.util.Objects.equals(conditionType, that.conditionType)) return false;
    if (!java.util.Objects.equals(polarity, that.polarity)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(conditionType,  polarity,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditionType != null) { sb.append("conditionType:"); sb.append(conditionType + ","); }
    if (polarity != null) { sb.append("polarity:"); sb.append(polarity + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
